@@ -50,12 +50,8 @@ def get_data(save_dataset_fd,documents):
     train_data.edge_attr = None
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
+    return train_data,test_data
 
-    train_data_dataset_path = os.path.join(save_dataset_fd, 'train_data.dataset')
-    test_data_dataset_path = os.path.join(save_dataset_fd, 'test_data.dataset')
-
-    torch.save(train_data, train_data_dataset_path)
-    torch.save(test_data, test_data_dataset_path)
 
 def makeIndividualData(file):
     connect = Grapher(file)
@@ -98,23 +94,15 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(json,saved_prediction_dataset_folder):
+def getDataForUniquePrediction(json):
     test_list_of_graphs = []
     documents = ConvertJsonToDocumentsObjects(json)[0]
     individual_data = makeIndividualData(documents)
     test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
-    saved_path = os.path.join(saved_prediction_dataset_folder, 'predictions_data.dataset')
-    torch.save(test_data, saved_path)
+    return test_data
 
-def load_train_test_split(save_fd):
-    train_data = torch.load(os.path.join(save_fd, 'train_data.dataset'))
-    test_data = torch.load(os.path.join(save_fd, 'test_data.dataset'))
-    return train_data, test_data
 
-def load_predictionData(save_fd):
-    predictions_data = torch.load(os.path.join(save_fd, 'predictions_data.dataset'))
-    return predictions_data
 
 
