@@ -21,10 +21,8 @@ def make_info(document):
     individual_data = from_networkx(G)
     return G, df, individual_data
 
-def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,json,labels_tab):
-    getDataForUniquePrediction(json,saved_prediction_dataset_folder)
-
-    predictions_data = load_predictionData(save_fd=saved_prediction_dataset_folder)
+def predictionsUnique(saved_model_folder,json,labels_tab):
+    predictions_data = getDataForUniquePrediction(json)
 
     model = torch.load(os.path.join(saved_model_folder, "saved_model.pt"))
 
